@@ -6,16 +6,19 @@ import (
 	"path/filepath"
 	"regexp"
 
-	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils/json"
+	"github.com/lmorg/murex/utils/lists"
 )
 
 func init() {
 	lang.DefineFunction("g", cmdLsG, types.Json)
+	lang.DefineFunction("!g", cmdLsNotG, types.Json)
 	lang.DefineFunction("rx", cmdLsRx, types.Json)
+	lang.DefineFunction("!rx", cmdLsRx, types.Json)
 	lang.DefineMethod("f", cmdLsF, types.ReadArray, types.Json)
+	//lang.DefineMethod("!f", cmdLsF, types.ReadArray, types.Json)
 }
 
 func cmdLsG(p *lang.Process) (err error) {
@@ -36,6 +39,38 @@ func cmdLsG(p *lang.Process) (err error) {
 	return
 }
 
+func cmdLsNotG(p *lang.Process) (err error) {
+	p.Stdout.SetDataType(types.Json)
+
+	glob, err := filepath.Glob(p.Parameters.StringAll())
+	if err != nil {
+		return
+	}
+
+	all, err := filepath.Glob("*")
+	if err != nil {
+		return
+	}
+
+	//files := make([]string, len(all))
+	//var length int
+	var files []string
+	for i := range all {
+		if !lists.Match(glob, all[i]) {
+			files = append(files, all[i])
+		}
+	}
+
+	//j, err := json.Marshal(files[:length], p.Stdout.IsTTY())
+	j, err := json.Marshal(files, p.Stdout.IsTTY())
+	if err != nil {
+		return
+	}
+
+	_, err = p.Stdout.Writeln(j)
+	return
+}
+
 func cmdLsRx(p *lang.Process) (err error) {
 	p.Stdout.SetDataType(types.Json)
 	rx, err := regexp.Compile(p.Parameters.StringAll())
@@ -50,7 +85,7 @@ func cmdLsRx(p *lang.Process) (err error) {
 
 	var matched []string
 	for i := range files {
-		if rx.MatchString(files[i]) {
+		if rx.MatchString(files[i]) != p.IsNot {
 			matched = append(matched, files[i])
 		}
 	}
@@ -86,7 +121,7 @@ func cmdLsF(p *lang.Process) (err error) {
 			p.Stderr.Writeln(usage)
 			return nil
 		default:
-			return errors.New("Invalid flag. `f -h` for usage")
+			return errors.New("invalid flag. `f -h` for usage")
 		}
 	}
 
@@ -104,12 +139,6 @@ func cmdLsF(p *lang.Process) (err error) {
 		}
 	}
 
-	if debug.Enabled {
-		for _, f := range files {
-			debug.Log("f->", f)
-		}
-	}
-
 	for i := range files {
 		if p.HasCancelled() {
 			break
