@@ -15,6 +15,7 @@ func init() {
 		"[[":                    "element_commands_docgen.go",
 		"[":                     "index_commands_docgen.go",
 		"a":                     "a_commands_docgen.go",
+		"addheading":            "addheading_commands_docgen.go",
 		"alias":                 "alias_commands_docgen.go",
 		"alter":                 "alter_commands_docgen.go",
 		"and":                   "and_commands_docgen.go",
@@ -27,6 +28,7 @@ func init() {
 		"catch":                 "catch_commands_docgen.go",
 		"cd":                    "cd_commands_docgen.go",
 		"config":                "config_commands_docgen.go",
+		"count":                 "count_commands_docgen.go",
 		"cpuarch":               "cpuarch_commands_docgen.go",
 		"cpucount":              "cpucount_commands_docgen.go",
 		"datetime":              "datetime_commands_docgen.go",
@@ -64,7 +66,6 @@ func init() {
 		"ja":                    "ja_commands_docgen.go",
 		"jsplit":                "jsplit_commands_docgen.go",
 		"left":                  "left_commands_docgen.go",
-		"len":                   "len_commands_docgen.go",
 		"let":                   "let_commands_docgen.go",
 		"lockfile":              "lockfile_commands_docgen.go",
 		"man-summary":           "man-summary_commands_docgen.go",
