@@ -17,7 +17,8 @@ var (
 func ExpandString(line string) string {
 	match := rxVars.FindAllString(line, -1)
 	for i := range match {
-		line = strings.Replace(line, match[i], lang.ShellProcess.Variables.GetString(match[i][1:]), -1)
+		s, _ := lang.ShellProcess.Variables.GetString(match[i][1:])
+		line = strings.Replace(line, match[i], s, -1)
 	}
 
 	match = rxHome.FindAllString(line, -1)
